@@ -1,9 +1,9 @@
 subroutine inipars(bvalue,model,ndat,xdat,&
                    ydat,outpars,tol,info)
 !--------------------------------------------------------------------------------------------
-! Subroutine inipars() is used to initialize parameters for dose-response model with the 
-! formla y=k*(1-exp(-b*x))+c or y=k*(1-exp(-b*x))+c*x+d, user need to privde b values and 
-! paired observations, then k, c (or k, c, d) can be estimated using Linear Algebra method.
+! Subroutine inipars() is used to initialize parameters for a growth curve with the 
+! formla y=k*(1-exp(-b*x))+c or y=k*(1-exp(-b*x))+c*x+d, with a privde b values and some
+! paired observations, k, c (or k, c, d) can be estimated using a Linear Algebra method.
 ! ===========================================================================================
 ! 
 ! model,                 input:: integer, model=3 for y=k*(1-exp(-b*x))+c;
@@ -21,13 +21,11 @@ subroutine inipars(bvalue,model,ndat,xdat,&
 !
 ! outpars(model-1),     output:: real values, estimated parameters (k and c, or k, c and d).
 !
-! info(2),              output:: integer values, error messages: 
-!                                1.1) if no error appears in array allocation, info(1)=0;
-!                                1.2) if error appears in array allocation, info(1)=1;
-!                                2.1) if vectors are linear indenpendent, info(2)=0;
-!                                2.2) if vectors are linear denpendent, info(2)=1.
+! info,                 output:: integer value, error message: 
+!                                1) if vectors are linear indenpendent, info=0;
+!                                2) if vectors are linear denpendent,   info=1.
 ! ===========================================================================================
-! Author:: Peng Jun, 2013.08.01.
+! Author:: Peng Jun, 2013.08.01; revised in 2014.04.02.
 !
 ! Dependence:: subroutine GJordan.
 !---------------------------------------------------------------------------------------------
@@ -38,36 +36,37 @@ subroutine inipars(bvalue,model,ndat,xdat,&
   real   (kind=8),                   intent(in)::tol
   real   (kind=8),dimension(ndat),   intent(in)::xdat, ydat
   real   (kind=8),dimension(model-1),intent(out)::outpars
-  integer(kind=4),                   intent(out)::info(2)
-  ! Local variables
-  real   (kind=8),dimension(:,:),allocatable::coeff
-  real   (kind=8),dimension(:,:),allocatable::coeffmatrix
-  real   (kind=8),dimension(:,:),allocatable::coeffy
-  real   (kind=8),dimension(ndat,1)::cydat
+  integer(kind=4),                   intent(out)::info
+  ! Local variables.
+  real   (kind=8),dimension(ndat,model-1)   ::coeff
+  real   (kind=8),dimension(ndat,3)         ::coeff3
+  real   (kind=8),dimension(model-1,model-1)::coeffmatrix
+  real   (kind=8),dimension(model-1,1)      ::coeffy
+  real   (kind=8),dimension(ndat,1)         ::cydat
   !
   info=0
-  ! Return -99.0 if error appears
+  coeff3=-99.0D+00
+  ! Return -99.0 if error appears.
   outpars=-99.0D+00
+  !
   if(model==3) then
-    allocate(coeff(ndat,2),coeffmatrix(2,2),coeffy(2,1),stat=info(1))
-    if(info(1)/=0) return
-    coeff(:,1)=1.0D+00-dexp(-bvalue*xdat)
-    coeff(:,2)=1.0D+00
+    coeff3(:,1)=1.0D+00-dexp(-bvalue*xdat)
+    coeff3(:,2)=1.0D+00
   else if(model==4) then
-    allocate(coeff(ndat,3),coeffmatrix(3,3),coeffy(3,1),stat=info(1))
-    if(info(1)/=0) return
-    coeff(:,1)=1.0D+00-dexp(-bvalue*xdat)
-    coeff(:,2)=xdat
-    coeff(:,3)=1.0D+00
+    coeff3(:,1)=1.0D+00-dexp(-bvalue*xdat)
+    coeff3(:,2)=xdat
+    coeff3(:,3)=1.0D+00
   end if
-  ! Calculate coefficients
+  ! 
   cydat(:,1)=ydat
+  coeff(:,1:model-1)=coeff3(:,1:model-1)
+  ! Calculate coefficients.
   coeffmatrix=matmul(transpose(coeff),coeff)
   coeffy=matmul(transpose(coeff),cydat)
-  call GJordan(coeffmatrix,coeffy,model-1,1,info(2),tol)
-  if(info(2)/=0) return
+  call GJordan(coeffmatrix,coeffy,model-1,1,info,tol)
+  ! Error checking.
+  if(info/=0) return
+  !
   outpars=coeffy(:,1)
-  deallocate(coeff,coeffmatrix,coeffy)
-  ! Now return
   return
 end subroutine inipars
